﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using DlhSoft.Windows.Controls;

namespace GanttChartTaskListViewCustomScaleSample
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();
        }

        // Prepare custom time scale, time scale text format, verical bar provider, and update scale instances to be used as specific scale-related settings.
        public static TimeScale CustomTimeScale
        {
            get
            {
                // Defines a time scale that is based on time scale periods of 12 hours (half of day) and indicates the special header text "Past" for all the past time scale periods.
                return new TimeScale(
                    delegate(DateTime start, DateTime finish)
                    {
                        // Get the next scale period start.
                        start = start.Date.AddHours((start.Hour / 12) * 12).AddHours(12);
                        // Prepare and return the list of time scale items based on the provided date and times.
                        DateTime today = DateTime.Today;
                        SortedList<DateTime, string> timeScaleItems = new SortedList<DateTime, string>();
                        for (DateTime dateTime = start; dateTime <= finish; dateTime = dateTime.AddHours(12))
                            timeScaleItems.Add(dateTime, dateTime < today ? "Past" : null);
                        return timeScaleItems;
                    });
            }
        }
        public static TimeScaleTextFormat CustomTimeScaleTextFormat
        {
            get
            {
                // Defines a time scale text format that returns either "AM" or "PM" for each time scale period.
                return new TimeScaleTextFormat(
                    delegate(DateTime dateTime)
                    {
                        // Prepare and return the string to be displayed based on the provided date and time.
                        return dateTime.Hour < 12 ? "AM" : "PM";
                    });
            }
        }
        public static GanttChartViewVerticalBarProvider CustomVerticalBarProvider
        {
            get
            {
                // Defines a vertical bar provider that indicates that yellow vertical bars should be drawn on the 1st, 11th, and 21rd of the current month, and at the end of the current month.
                return new GanttChartViewVerticalBarProvider(
                    delegate(DateTime start, DateTime finish)
                    {
                        // Prepare and return the list of vertical bars based on the provided date and times.
                        DateTime today = DateTime.Today;
                        DateTime firstOfMonth = new DateTime(today.Year, today.Month, 1);
                        DateTime firstOfNextMonth = firstOfMonth.AddMonths(1);
                        SortedList<DateTime, VerticalBar> verticalBars = new SortedList<DateTime, VerticalBar>();
                        for (DateTime dateTime = firstOfMonth; dateTime < firstOfMonth.AddDays(30); dateTime = dateTime.AddDays(10))
                            verticalBars.Add(dateTime, new VerticalBar(null, Brushes.Yellow, new Thickness(0, 0, 1, 0)));
                        verticalBars.Add(firstOfNextMonth, new VerticalBar(null, Brushes.Yellow, new Thickness(0, 0, 1, 0)));
                        return verticalBars;
                    });
            }
        }
        public static GanttChartViewUpdateScale CustomUpdateScale
        {
            get
            {
                // Defines an update scale that limits updates on 10 minutes duration invervals.
                return new GanttChartViewUpdateScale(
                    delegate(DateTime dateTime)
                    {
                        // Prepare and return the date and time to do the update at based on the provided date and times.
                        return dateTime.Date.AddHours(dateTime.Hour).AddMinutes(dateTime.Minute / 10 * 10);
                    });
            }
        }

        // Manage update scale.
        private GanttChartViewUpdateScale originalUpdateScale = null;
        private void CustomUpdateScaleMenuItem_Checked(object sender, RoutedEventArgs e)
        {
            originalUpdateScale = GanttChartTaskListView.UpdateScale;
            GanttChartTaskListView.UpdateScale = CustomUpdateScale;
        }
        private void CustomUpdateScaleMenuItem_Unchecked(object sender, RoutedEventArgs e)
        {
            GanttChartTaskListView.UpdateScale = originalUpdateScale;
            originalUpdateScale = null;
        }

        // Manage zoom.
        private double originalZoom = 0;
        private void CustomZoomMenuItem_Checked(object sender, RoutedEventArgs e)
        {
            originalZoom = GanttChartTaskListView.HourWidth;
            GanttChartTaskListView.HourWidth = 27;
        }
        private void CustomZoomMenuItem_Unchecked(object sender, RoutedEventArgs e)
        {
            GanttChartTaskListView.HourWidth = originalZoom;
            originalZoom = 0;
        }
    }
}
